@@ -495,7 +495,8 @@ class BaseExperiment:
         self._create_folder(folder_dir)
         version = len(os.listdir(folder_dir)) - 1
         log_dir = folder_dir + "/" + self.model_metadata + "/" + "version_{}".format(version)
-        self._create_folder(log_dir)
+        if version >= 0:
+            self._create_folder(log_dir)
         self.logger = SummaryWriter(log_dir=log_dir)
         self.model.fit(self.X_train, self.y_train, sample_weight)
         y_train_preds = self.model.predict(self.X_train)
@@ -1077,6 +1078,11 @@ class BaseExperiment:
 
     @staticmethod
     def _dict_to_str(dictionary : dict)->str:
-        r"""Polishes string form of the dictionary."""
+        r"""Polishes string form of the dictionary. Applied when defining hparams and using **hparams to pass arguments."""
         out = str(dictionary).replace("{", "").replace("}","").replace(" ","-").replace(":","").replace("-","").replace("\n", "-").replace('"', "").replace(".","d").replace("'","")
+        return out
+
+    def _args_to_str(*args)->str:
+        r"""Polishes string form of the args when not. Applited when passing arguments as *args"""
+        out = str(args).replace(",","_")
         return out
\ No newline at end of file
